@@ -1,4 +1,5 @@
-﻿define(['libraryBrowser', 'alphaPicker', 'listView', 'cardBuilder', 'emby-itemscontainer'], function (libraryBrowser, alphaPicker, listView, cardBuilder) {
+﻿define(['libraryBrowser', 'alphaPicker', 'listView', 'cardBuilder', 'imageLoader', 'emby-itemscontainer'], function (libraryBrowser, alphaPicker, listView, cardBuilder, imageLoader) {
+    'use strict';
 
     return function (view, params) {
 
@@ -120,6 +121,7 @@
                     posterOptions.showYear = true;
                     posterOptions.cardLayout = true;
                     posterOptions.centerText = false;
+                    posterOptions.vibrant = true;
 
                     html = cardBuilder.getCardsHtml(posterOptions);
                 }
@@ -159,7 +161,7 @@
 
                 var elem = view.querySelector('#items');
                 elem.innerHTML = html;
-                ImageLoader.lazyChildren(elem);
+                imageLoader.lazyChildren(elem);
 
                 var i, length;
                 var elems = view.querySelectorAll('.paging');
@@ -241,36 +243,6 @@
             valueChangeEvent: 'click'
         });
 
-        function parentWithClass(elem, className) {
-
-            while (!elem.classList || !elem.classList.contains(className)) {
-                elem = elem.parentNode;
-
-                if (!elem) {
-                    return null;
-                }
-            }
-
-            return elem;
-        }
-
-        view.addEventListener('click', function (e) {
-
-            var mediaItem = parentWithClass(e.target, 'mediaItem');
-            if (mediaItem) {
-                var query = getQuery();
-                var info = libraryBrowser.getListItemInfo(mediaItem);
-
-                if (info.mediaType == 'Photo') {
-                    require(['scripts/photos'], function () {
-                        Photos.startSlideshow(view, query, info.id);
-                    });
-                    e.preventDefault();
-                    return false;
-                }
-            }
-        });
-
         function updateFilterControls() {
 
             var query = getQuery();
@@ -361,7 +333,6 @@
         view.addEventListener('viewbeforeshow', function (e) {
             reloadItems(view);
             updateFilterControls();
-            LibraryMenu.setBackButtonVisible(params.context);
         });
 
         view.addEventListener('viewdestroy', function (e) {
